@@ -39,3 +39,7 @@ class OperatorSizerConfigMessage(BaseEventMessage):
 
 class OperatorMarketSpreadsMessage(BaseEventMessage):
     market_spreads: Dict[str, Any]
+
+
+class OperatorUSDCLPStock(BaseEventMessage):
+    stock: Dict[str, Any]
